@@ -162,6 +162,7 @@ def application(
     icon=None,  # XXX in favor of explicit mount
     mounts=None,
     automount=False,
+    autotemplate=False,
     wrappers=None,
     sessions=False,  # XXX in favor of explicitly wrapper
     host=None,
@@ -188,6 +189,7 @@ def application(
             port=port,
             mounts=mounts,
             automount=automount,
+            autotemplate=autotemplate,
             wrappers=wrappers,
             args=args,
         )
@@ -736,6 +738,7 @@ class Application:
         sessions=False,
         mounts=None,
         automount=False,
+        autotemplate=False,
         wrappers=None,
         host=None,
         port=False,
@@ -786,13 +789,18 @@ class Application:
         #     self.add_wrappers(*mounted_app.wrappers)
         #     mounted_app.wrappers = []
 
-        try:
-            self.view = templating.templates(name)
-        except ModuleNotFoundError:
+        self.view = None
+        self.autotemplate = autotemplate
+        if self.autotemplate:
             try:
                 self.view = templating.TemplatePackage("templates")
             except (AttributeError, ModuleNotFoundError):
                 pass
+        if not self.view:
+            try:
+                self.view = templating.templates(name)
+            except ModuleNotFoundError:
+                pass
 
         self.static_path = pathlib.Path("static")
         if not self.static_path.exists():
@@ -1167,10 +1175,7 @@ class Application:
                 try:
                     template = self.view.template
                 except AttributeError:
-                    try:
-                        template = 3  # XXXXXX
-                    except:
-                        template = lambda x: x
+                    template = lambda x: x
                 tx.response.body = template(tx.response.body)
 
         exhaust_hooks()  # here for mandatory wrappers (eg. session handling)
